@@ -2,11 +2,11 @@
 #define	gdbmobj_h
 
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2007 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
-static const char gdbmobj_h_rcsid[]="$Id: gdbmobj.h,v 1.6 1999/12/06 13:14:46 mrsam Exp $";
+static const char gdbmobj_h_rcsid[]="$Id: gdbmobj.h,v 1.7 2007/03/01 04:32:04 mrsam Exp $";
 
 #include	"gdbm.h"
 
@@ -42,6 +42,8 @@ char	*gdbmobj_nextkey(struct gdbmobj *, size_t *, char **, size_t *);
 #ifdef	__cplusplus
 } ;
 
+#include <string>
+
 class GdbmObj {
 
 	struct gdbmobj obj;
@@ -52,13 +54,82 @@ class GdbmObj {
 public:
 	GdbmObj()	{ gdbmobj_init(&obj); }
 	~GdbmObj()	{ gdbmobj_close(&obj); }
-	int	Open(const char *filename, const char *mode)
-		{
-			return ( gdbmobj_open(&obj, filename, mode));
-		}
+	int	Open(std::string filename, const char *mode)
+	{
+		return ( gdbmobj_open(&obj, filename.c_str(), mode));
+	}
 
 	int	IsOpen() { return (gdbmobj_isopen(&obj)); }
 	void	Close() { gdbmobj_close(&obj); }
+
+	std::string Fetch(std::string key, std::string mode)
+	{
+		size_t l;
+		char *p=Fetch(key.c_str(), key.size(), l, mode.c_str());
+
+		if (!p) return "";
+
+		std::string v(p, p+l);
+
+		free(p);
+		return v;
+	}
+
+	bool	Exists(std::string key)
+	{
+		return !!Exists(key.c_str(), key.size());
+	}
+
+	bool	Delete(std::string key)
+	{
+		return !!Delete(key.c_str(), key.size());
+	}
+
+	int	Store(std::string key, std::string val, std::string mode)
+	{
+		return Store(key.c_str(), key.size(),
+			     val.c_str(), val.size(), mode.c_str());
+	}
+
+	std::string FetchFirstKeyVal(std::string &valRet)
+	{
+		char *key;
+		size_t keyLen;
+		char *val;
+		size_t valLen;
+
+		key=FetchFirstKeyVal(keyLen, val, valLen);
+
+		if (!key)
+			return "";
+
+		std::string r(key, key+keyLen);
+
+		valRet=std::string(val, val+valLen);
+		free(val);
+		return r;
+	}
+
+	std::string FetchNextKeyVal(std::string &valRet)
+	{
+		char *key;
+		size_t keyLen;
+		char *val;
+		size_t valLen;
+
+		key=FetchNextKeyVal(keyLen, val, valLen);
+
+		if (!key)
+			return "";
+
+		std::string r(key, key+keyLen);
+
+		valRet=std::string(val, val+valLen);
+		free(val);
+		return r;
+	}
+
+
 	char	*Fetch(const char *key, size_t keylen,
 			size_t &valuelen, const char *mode)
 		{
