@@ -1,5 +1,5 @@
 /*
-** Copyright 2001 Double Precision, Inc.
+** Copyright 2001-2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -196,13 +196,19 @@ static void check_dsn()
 	p=hdr("precedence");
 
 	if (strncasecmp(p, "junk", 4) == 0 ||
-	    strncasecmp(p, "bulk", 4) == 0)
+	    strncasecmp(p, "bulk", 4) == 0 ||
+	    strncasecmp(p, "list", 4) == 0)
 		exit(0);	/* Just in case */
 
 	p=hdr("auto-submitted");
 
 	if (*p && strcmp(p, "no"))
 		exit(0);
+
+	p=hdr("list-id");
+
+	if (*p)
+		exit(0);
 }
 
 /*
@@ -413,8 +419,7 @@ static FILE *opensendmail(int argn, int argc, char **argv)
 		if (waitstat)
 			exit(waitstat);
 
-		close(0);
-		dup(pipefd[0]);
+		dup2(pipefd[0], 0);
 		close(pipefd[0]);
 		close(pipefd[1]);
 
