@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: reftest.c,v 1.5 2001/01/14 21:03:57 mrsam Exp $
+** $Id: reftest.c,v 1.7 2003/05/30 01:24:16 mrsam Exp $
 */
 
 #include	"config.h"
@@ -87,17 +87,17 @@ static void test2()
 
 	rfc822_threadmsg(mt, "<1>", NULL,
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<2>",
 			 "<1>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<4>",
 			 "<1> <2> <3>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	prpc(mt);
 	rfc822_threadfree(mt);
@@ -110,21 +110,21 @@ static void test3()
 	rfc822_threadmsg(mt, "<4>",
 			 "<2> <1> <3>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<3>",
 			 "<1> <2>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<2>",
 			 "<1>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<1>", NULL,
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	prpc(mt);
 	rfc822_threadfree(mt);
@@ -136,15 +136,15 @@ static void test4()
 
 	rfc822_threadmsg(mt, "<1>", NULL,
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<2>", "<1>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<4>", "<1> <2> <3>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	prpc(mt);
 	rfc822_threadprune(mt);
@@ -158,11 +158,11 @@ static void test5()
 
 	rfc822_threadmsg(mt, "<4>", "<1> <2> <3>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<3>", NULL,
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	prpc(mt);
 	rfc822_threadprune(mt);
@@ -188,31 +188,31 @@ static void test6()
 
 	rfc822_threadmsg(mt, "<message1>", NULL,
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message10>", NULL,
 			 "subject 2",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 2);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 2);
 
 	rfc822_threadmsg(mt, "<message3>", "<message2>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 3);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 3);
 
 	rfc822_threadmsg(mt, "<message11>", NULL,
 			 "Re: subject 4",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 4);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 4);
 
 	rfc822_threadmsg(mt, "<message12>", NULL,
 			 "subject 4",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 5);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 5);
 
 	rfc822_threadmsg(mt, "<message13>", NULL,
 			 "subject 5",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 6);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 6);
 
 	rfc822_threadmsg(mt, "<message14>", NULL,
 			 "re: subject 5",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 7);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 7);
 
 	rfc822_threadprune(mt);
 	rfc822_threadsortsubj(rfc822_threadgetroot(mt));
@@ -228,11 +228,11 @@ static void test7()
 
 	rfc822_threadmsg(mt, "<message1>", "<message1-dummy>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message2>", "<message2-dummy>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:58 -0700", 0, 1);
 	rfc822_threadprune(mt);
 	rfc822_threadsortsubj(rfc822_threadgetroot(mt));
 	rfc822_threadgathersubj(mt, rfc822_threadgetroot(mt));
@@ -249,27 +249,27 @@ static void test8()
 
 	rfc822_threadmsg(mt, "<message4>", NULL,
 			 "subject 2",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:51 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message2>", NULL,
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:52 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message1>", "<message1-dummy>",
 			 "subject 1",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:53 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message3>", NULL,
 			 "Re: subject 2",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:54 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message10>", NULL,
 			 "subject 10",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:55 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message11>", NULL,
 			 "subject 10",
-			 "Thu, 29 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 29 Jun 2000 14:41:56 -0700", 0, 1);
 
 	rfc822_threadprune(mt);
 	rfc822_threadsortsubj(rfc822_threadgetroot(mt));
@@ -287,27 +287,27 @@ static void test9()
 
 	rfc822_threadmsg(mt, "<message1>", NULL,
 			 "subject 1",
-			 "Thu, 20 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 20 Jun 2000 14:41:55 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message2>", NULL,
 			 "subject 1",
-			 "Thu, 19 Jun 2000 14:41:58 -0700", 2);
+			 "Thu, 19 Jun 2000 14:41:51 -0700", 0, 2);
 
 	rfc822_threadmsg(mt, "<message3>", NULL,
 			 "subject 1",
-			 "Thu, 21 Jun 2000 14:41:58 -0700", 3);
+			 "Thu, 21 Jun 2000 14:41:56 -0700", 0, 3);
 
 	rfc822_threadmsg(mt, "<message4>", "<message2>",
 			 "subject 2",
-			 "Thu, 21 Jun 2000 14:41:58 -0700", 6);
+			 "Thu, 21 Jun 2000 14:41:54 -0700", 0, 6);
 
 	rfc822_threadmsg(mt, "<message5>", "<message2>",
 			 "subject 2",
-			 "Thu, 21 Jun 2000 14:41:58 -0700", 5);
+			 "Thu, 21 Jun 2000 14:41:53 -0700", 0, 5);
 
 	rfc822_threadmsg(mt, "<message6>", "<message2>",
 			 "subject 2",
-			 "Thu, 20 Jun 2000 14:41:58 -0700", 4);
+			 "Thu, 20 Jun 2000 14:41:52 -0700", 0, 4);
 
 
 	rfc822_threadprune(mt);
@@ -325,19 +325,19 @@ static void test10()
 
 	rfc822_threadmsg(mt, "<message1>", NULL,
 			 "subject 1",
-			 "Thu, 20 Jun 2000 14:41:58 -0700", 1);
+			 "Thu, 20 Jun 2000 14:41:58 -0700", 0, 1);
 
 	rfc822_threadmsg(mt, "<message4>", "<message1>",
 			 "subject 2",
-			 "Thu, 21 Jun 2000 14:41:58 -0700", 6);
+			 "Thu, 21 Jun 2000 14:41:58 -0700", 0, 6);
 
 	rfc822_threadmsg(mt, "<message1>", NULL,
 			 "subject 2",
-			 "Thu, 21 Jun 2000 14:41:58 -0700", 5);
+			 "Thu, 21 Jun 2000 14:41:58 -0700", 0, 5);
 
 	rfc822_threadmsg(mt, "<message4>", "<message1>",
 			 "subject 2",
-			 "Thu, 21 Jun 2000 14:41:58 -0700", 6);
+			 "Thu, 21 Jun 2000 14:41:58 -0700", 0, 6);
 
 	rfc822_threadprune(mt);
 	rfc822_threadsortsubj(rfc822_threadgetroot(mt));
